@@ -266,7 +266,7 @@ for (var i = p.length; --i >= 0; ) p[i] = params[i];
 
 var qcoefs = this.getQCoefs (key);
 if (qcoefs == null) {
-System.err.println ("Missing cell wave vector for atom wave vector for " + key + " " + JU.Escape.e (params));
+System.err.println ("MSRdr missing cell wave vector for atom wave vector for " + key + " " + JU.Escape.e (params));
 break;
 }this.addAtomModulation (atomName, axis, type, p, utens, qcoefs);
 this.haveAtomMods = true;
@@ -298,6 +298,7 @@ Clazz.overrideMethod (c$, "getQCoefs",
 function (key) {
 var fn = Math.max (0, this.cr.parseIntAt (key, 2));
 if (fn == 0) {
+System.err.println ("MSRdr missing cell wave vector for atom wave vector for " + key);
 if (this.qlist100 == null) {
 this.qlist100 =  Clazz.newDoubleArray (this.modDim, 0);
 this.qlist100[0] = 1;
