@@ -41,6 +41,7 @@ this.getHeader = false;
 this.isSequential = false;
 this.optimize2D = false;
 this.noHydrogens = false;
+this.noMinimize = false;
 this.is2D = false;
 this.isMolecular = false;
 this.templateAtomCount = 0;
@@ -656,7 +657,8 @@ this.allow_a_len_1 = this.checkFilterKey ("TOPOS");
 this.slabXY = this.checkFilterKey ("SLABXY");
 this.polymerX = !this.slabXY && this.checkFilterKey ("POLYMERX");
 this.noHydrogens = this.checkFilterKey ("NOH");
-this.optimize2D = this.checkFilterKey ("2D") && !this.noHydrogens;
+this.noMinimize = this.checkFilterKey ("NOMIN");
+this.optimize2D = this.checkFilterKey ("2D") && !this.noHydrogens && !this.noMinimize;
 if (this.filter == null) return;
 if (this.checkFilterKey ("HETATM")) {
 this.filterHetero = true;
@@ -753,10 +755,18 @@ return (f.indexOf (code) >= 0 && (f.indexOf ("!" + code) >= 0) == (f.indexOf (co
 Clazz.defineMethod (c$, "set2D", 
 function () {
 this.asc.setInfo ("is2D", Boolean.TRUE);
-if (this.checkFilterKey ("NOH")) this.asc.setInfo ("noHydrogen", Boolean.TRUE);
-if (!this.checkFilterKey ("NOMIN")) this.asc.setInfo ("doMinimize", Boolean.TRUE);
-this.appendLoadNote ("This model is 2D. Its 3D structure will be generated.");
-});
+this.asc.getBSAtoms (-1);
+if (this.noHydrogens) {
+this.asc.setInfo ("noHydrogen", Boolean.TRUE);
+this.optimize2D = false;
+}if (this.optimize2D) {
+this.asc.fix2Stereo ();
+this.asc.setInfo ("doMinimize", Boolean.TRUE);
+this.appendLoadNote ("This model is 2D. Its 3D structure was generated.");
+} else {
+this.appendLoadNote ("This model is 2D. Its 3D structure has not been generated; use LOAD \"\" FILTER \"2D\" to optimize 3D.");
+this.addJmolScript ("select thismodel;wireframe only");
+}});
 Clazz.defineMethod (c$, "doGetVibration", 
 function (vibrationNumber) {
 return this.addVibrations && (this.desiredVibrationNumber <= 0 || vibrationNumber == this.desiredVibrationNumber);
