@@ -4,4 +4,7 @@ Clazz.defineStatics (c$,
 "PDB_CARTOONS", 1,
 "NO_SCRIPT", 2,
 "IS_APPEND", 4,
-"NO_AUTOPLAY", 8);
+"NO_AUTOPLAY", 8,
+"FILE_DROPPED", 16,
+"SCRIPT_ONLY", 32,
+"CHECK_DIMS", 64);
