@@ -41,7 +41,7 @@ var scale = axes.scale;
 if (isabcxyz) {
 if ("xyzabc".equals (axes.axes2)) this.render1 (axes, mad10, false, axisType, isUnitCell, 2, null);
 if (!"abc".equals (axes.axes2)) this.vwr.setBooleanProperty ("axesmolecular", true);
-axes.initShape ();
+axes.reinitShape ();
 this.render1 (axes, mad10, true, null, false, scale, axes.axes2);
 this.vwr.setBooleanProperty ("axesunitcell", true);
 } else {
