@@ -646,8 +646,10 @@ for (var j = 1; j <= count; j++) sb.append (" ").append (m.getLabel (j, true, tr
 if (isProperty) {
 sb.append (" " + m.property + " value " + (Double.isNaN (m.value) ? 0 : m.value)).append (" " + JU.PT.esc (m.getString ()));
 } else if (count == 2) {
-var s = m.getStrFormatForState ();
+var s = m.getDistanceFormatForState ();
 if (s != null) sb.append (" ").append (JU.PT.esc (s));
+}if (!isProperty) {
+sb.append ("; # " + shape.getInfoAsString (i));
 }this.app (commands, sb.toString ());
 }
 this.app (commands, J.shape.Shape.getFontCommand ("measures", font3d));
